@@ -1,10 +1,12 @@
 # ABSTRACT: helper for rendering HTTP status codes for Dancer2
 
 package Dancer2::Core::HTTP;
-$Dancer2::Core::HTTP::VERSION = '0.202000';
+$Dancer2::Core::HTTP::VERSION = '0.203000';
 use strict;
 use warnings;
 
+use List::Util qw/ pairmap pairgrep /;
+
 my $HTTP_CODES = {
 
     # informational
@@ -92,13 +94,11 @@ my $HTTP_CODES = {
     599 => 'Network connect timeout error',
 };
 
-for my $code ( keys %$HTTP_CODES ) {
-    my $str_http_code = $HTTP_CODES->{$code};
-    $HTTP_CODES->{$str_http_code} = $code;
-
-    my $alias = lc join '_', split /\W/, $HTTP_CODES->{$code};
-    $HTTP_CODES->{$alias} = $code;
-}
+$HTTP_CODES = {
+    %$HTTP_CODES,
+    ( reverse %$HTTP_CODES ),
+    pairmap { join( '_', split /\W/, lc $a ) => $b } reverse %$HTTP_CODES
+};
 
 $HTTP_CODES->{error} = $HTTP_CODES->{internal_server_error};
 
@@ -120,6 +120,17 @@ sub status_message {
     return $HTTP_CODES->{ $code };
 }
 
+sub status_mapping {
+    pairgrep { $b =~ /^\d+$/ and $a !~ /_/ } %$HTTP_CODES;
+}
+
+sub code_mapping {
+    my @result = reverse status_mapping();
+    return @result;
+}
+
+sub all_mappings { %$HTTP_CODES }
+
 1;
 
 __END__
@@ -134,7 +145,7 @@ Dancer2::Core::HTTP - helper for rendering HTTP status codes for Dancer2
 
 =head1 VERSION
 
-version 0.202000
+version 0.203000
 
 =head1 FUNCTIONS
 
@@ -158,6 +169,28 @@ status.
 
 Returns the HTTP status message for the given status code.
 
+=head2 status_mapping()
+
+    my %table = Dancer2::Core::HTTP->status_mapping;
+    # returns ( 'Ok' => 200, 'Created' => 201, ... )
+
+Returns the full table of status -> code mappings.
+
+=head2 code_mapping()
+
+    my %table = Dancer2::Core::HTTP->code_mapping;
+    # returns ( 200 => 'Ok', 201 => 'Created', ... )
+
+Returns the full table of code -> status mappings.
+
+=head2 all_mappings()
+
+    my %table = Dancer2::Core::HTTP->all_mappings;
+    # returns ( 418 => 'I'm a teapot', "I'm a teapot' => 418, 'i_m_a_teapot' => 418 )
+
+Returns the code-to-status, status-to-code and underscore-groomed status-to-code mappings
+all mashed up in a single table. Mostly for internal uses.
+
 =head1 AUTHOR
 
 Dancer Core Developers
