@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::SessionFactory::File;
 # ABSTRACT: Role for file-based session factories
-$Dancer2::Core::Role::SessionFactory::File::VERSION = '0.202000';
+$Dancer2::Core::Role::SessionFactory::File::VERSION = '0.203000';
 use Moo::Role;
 with 'Dancer2::Core::Role::SessionFactory';
 
@@ -8,6 +8,7 @@ use Carp 'croak';
 use Dancer2::Core::Types;
 use Dancer2::FileUtils qw(path set_file_mode escape_filename);
 use Fcntl ':flock';
+use File::Copy ();
 
 #--------------------------------------------------------------------------#
 # Required by classes consuming this role
@@ -73,6 +74,20 @@ sub _retrieve {
     return $data;
 }
 
+sub _change_id {
+    my ($self, $old_id, $new_id) = @_;
+
+    my $old_path =
+      path($self->session_dir, escape_filename($old_id) . $self->_suffix);
+
+    return if !-f $old_path;
+
+    my $new_path =
+      path($self->session_dir, escape_filename($new_id) . $self->_suffix);
+
+    File::Copy::move($old_path, $new_path);
+}
+
 sub _destroy {
     my ( $self, $id ) = @_;
     my $session_file = path( $self->session_dir, escape_filename($id) . $self->_suffix );
@@ -110,7 +125,7 @@ Dancer2::Core::Role::SessionFactory::File - Role for file-based session factorie
 
 =head1 VERSION
 
-version 0.202000
+version 0.203000
 
 =head1 DESCRIPTION
 
